@@ -9,11 +9,10 @@ Exports:
 - Database: DatabaseService
 - Message bus: RedisBus, MemoryBus
 - Tool registry: ToolRegistry, discover_tools, bind_tools
-- Coordinator: CoordinatorRuntime
 - MCP: MCPToolSource, MCPToolRegistry
 """
 
-from .agent import Agent
+from .agent_runtime import Agent, AgentMemory
 from .cache import InMemoryCache, RedisCache
 from .config import (
     AgentConfig,
@@ -27,7 +26,7 @@ from .config import (
     QueueBackend,
     VectorBackend,
 )
-from .backends.database import (
+from .database import (
     AgentRegistry,
     DatabaseService,
     Job,
@@ -35,11 +34,60 @@ from .backends.database import (
     PromptExecution,
     Trace,
 )
-from .decorators import actor
+from .decorators import actor, tool
+from .workflow import Workflow
 from .llm import AnthropicLLM, GeminiLLM, NoOpLLM, OpenAILLM
 from .mcp_client import MCPToolRegistry, MCPToolSource
-from .backends.queue import MemoryBus, RedisBus, ResponseMessage, TaskMessage
-from .runtime_entry import AgentRunner, run_agent
+from .message_bus import MemoryBus, RedisBus, ResponseMessage, TaskMessage
+from .runtime_entry import AgentRunner, run_agent, WorkerRunner
+
+__all__ = [
+    # Primary runtime
+    "Agent",
+    "AgentMemory",
+    # Decorators
+    "actor",
+    "tool",
+    # Workflow
+    "Workflow",
+    # Backends and config
+    "InMemoryCache",
+    "RedisCache",
+    "AgentConfig",
+    "BackendFactory",
+    "CacheBackendProtocol",
+    "DatabaseBackend",
+    "EvenAgeConfig",
+    "LLMBackend",
+    "PipelineConfig",
+    "ProjectConfig",
+    "QueueBackend",
+    "VectorBackend",
+    # Database exports
+    "AgentRegistry",
+    "DatabaseService",
+    "Job",
+    "Memory",
+    "PromptExecution",
+    "Trace",
+    # LLMs
+    "AnthropicLLM",
+    "GeminiLLM",
+    "NoOpLLM",
+    "OpenAILLM",
+    # MCP
+    "MCPToolRegistry",
+    "MCPToolSource",
+    # Message bus
+    "MemoryBus",
+    "RedisBus",
+    "ResponseMessage",
+    "TaskMessage",
+    # Runner
+    "AgentRunner",
+    "WorkerRunner",
+    "run_agent",
+]
 from .tooling import (
     Tool,
     ToolRegistry,
@@ -49,9 +97,6 @@ from .tooling import (
     register_mcp_tools,
     tool,
 )
-from .backends.vector import LocalVectorStore
-from .backends.storage import InMemoryStorage, MinIOStorage
-
 
 # Backward-compatible aliases for protocol types
 LLMBase = LLMBackend
@@ -60,6 +105,7 @@ VectorBase = VectorBackend
 __all__ = [
     # Core classes
     "Agent",
+    "AgentMemory",
     "AgentRunner",
     "run_agent",
     # Decorators
@@ -90,6 +136,7 @@ __all__ = [
     "bind_tools",
     "register_mcp_tools",
     "create_tool_schema",
+    # Coordinator
     # MCP
     "MCPToolSource",
     "MCPToolRegistry",
@@ -106,9 +153,6 @@ __all__ = [
     "OpenAILLM",
     "AnthropicLLM",
     "GeminiLLM",
-    "LocalVectorStore",
-    "InMemoryStorage",
-    "MinIOStorage",
     "LLMBase",
     "VectorBase",
 ]
