@@ -184,12 +184,35 @@ class Agent:
         self._extra_instructions: str | None = (instructions or None)
 
     async def _llm_generate(self, prompt: str, system: str | None = None, **kwargs) -> str:
-        """Generate with primary LLM and fallbacks with default params merged."""
+        """Generate with primary LLM and fallbacks with default params merged.
+
+        If the backend supports generate_with_usage, capture token usage and emit a trace
+        event 'llm_usage' with provider/model and token counts for per-job accounting.
+        """
         params = {**self._llm_params, **(kwargs or {})}
         errors: list[str] = []
         backends = [self.llm] + [b for b in self._llm_fallbacks if b is not None]
         for backend in backends:
             try:
+                # Prefer usage-aware API if available
+                if hasattr(backend, "generate_with_usage"):
+                    text, usage = await backend.generate_with_usage(prompt, system=system, **params)  # type: ignore[attr-defined]
+                    # Trace usage if available
+                    try:
+                        if isinstance(usage, dict):
+                            payload = {
+                                "provider": usage.get("provider"),
+                                "model": usage.get("model"),
+                                "prompt_tokens": usage.get("prompt_tokens"),
+                                "completion_tokens": usage.get("completion_tokens"),
+                                "total_tokens": usage.get("total_tokens"),
+                                "worker": self.config.name,
+                            }
+                            self._trace(self.current_job_id or "unknown", self.config.name, "llm_usage", payload)
+                    except Exception:
+                        pass
+                    return text
+                # Fallback to text-only generation
                 return await backend.generate(prompt, system=system, **params)
             except Exception as e:
                 errors.append(str(e))
@@ -199,8 +222,10 @@ class Agent:
     def _register_system_tools(self):
         """Register built-in system tools for delegation and artifacts."""
         from .system_tools import create_system_tools
+        from .tooling import Tool as _Tool
 
-        system_tools = create_system_tools(self.bus, self.storage)
+        # Pass self (agent instance) so system tools can access current_job_id
+        system_tools = create_system_tools(self.bus, self.storage, agent=self)
 
         # Disallow any system tool that could bypass delegation safeguards
         reserved = {"delegate", "publish", "publish_task"}
@@ -209,9 +234,15 @@ class Agent:
             # Skip reserved/unsafe tool names
             if name in reserved:
                 continue
-            # Register each system tool
+            # Register each system tool with the explicit provided name,
+            # not the callable's __name__, so both prefixed and alias names exist.
             if not self.tools.has(name):
-                self.tools.register(func)
+                try:
+                    desc = (func.__doc__ or "").strip().split("\n")[0]
+                    self.tools.register(_Tool(name=name, func=func, description=desc))
+                except Exception:
+                    # Fallback to direct registration
+                    self.tools.register(func)
 
     async def connect_bus(self) -> None:
         """
@@ -320,11 +351,18 @@ class Agent:
         )
 
         # Trace start (log as prompt_id for new terminology)
+        from datetime import datetime as _dt
+        task_started_at = _dt.utcnow().isoformat() + "Z"
+        
         self._trace(
             execution_id,
             self.config.name,
             "task_start",
-            {"inputs": task}
+            {
+                "inputs": task,
+                "worker": self.config.name,
+                "started_at": task_started_at
+            }
         )
 
         try:
@@ -350,11 +388,16 @@ class Agent:
                 result = await self.execute_plan(plan, task)
 
             # Trace completion
+            task_ended_at = _dt.utcnow().isoformat() + "Z"
             self._trace(
                 execution_id,
                 self.config.name,
                 "task_complete",
-                {"result": result}
+                {
+                    "result": result,
+                    "worker": self.config.name,
+                    "ended_at": task_ended_at
+                }
             )
 
             # Auto-route result to coordinator if applicable
@@ -383,11 +426,16 @@ class Agent:
 
         except Exception as e:
             # Trace error
+            task_error_at = _dt.utcnow().isoformat() + "Z"
             self._trace(
                 execution_id,
                 self.config.name,
                 "task_error",
-                {"error": str(e)}
+                {
+                    "error": str(e),
+                    "worker": self.config.name,
+                    "ended_at": task_error_at
+                }
             )
 
             return {
@@ -525,12 +573,20 @@ class Agent:
             raise ValueError(f"Tool input validation failed: {e}")
 
         # Trace tool call if enabled
+        from datetime import datetime as _dt
+        started_at = _dt.utcnow().isoformat() + "Z"
+        
         if getattr(tool, "trace_enabled", True) and "tool_call" not in getattr(tool, "trace_mask", set()):
             self._trace(
                 self.current_job_id or "unknown",
                 self.config.name,
                 "tool_call",
-                {"tool": name, "params": validated_params}
+                {
+                    "tool": name,
+                    "params": validated_params,
+                    "worker": self.config.name,
+                    "started_at": started_at
+                }
             )
 
         # Execute
@@ -546,6 +602,7 @@ class Agent:
                 # If inspection fails, proceed with returned value
                 pass
             duration_ms = int((time.time() - start) * 1000)
+            ended_at = _dt.utcnow().isoformat() + "Z"
 
             # Trace tool_result if enabled
             if getattr(tool, "trace_enabled", True) and "tool_result" not in getattr(tool, "trace_mask", set()):
@@ -555,6 +612,9 @@ class Agent:
                     "tool_result",
                     {
                         "tool": name,
+                        "worker": self.config.name,
+                        "started_at": started_at,
+                        "ended_at": ended_at,
                         "duration_ms": duration_ms,
                         "status": "success",
                         # Store both a lightweight preview and the full result when reasonable
@@ -570,11 +630,20 @@ class Agent:
             return result
 
         except Exception as e:
+            ended_at = _dt.utcnow().isoformat() + "Z"
+            duration_ms = int((time.time() - start) * 1000)
             self._trace(
                 self.current_job_id or "unknown",
                 self.config.name,
                 "tool_error",
-                {"tool": name, "error": str(e)}
+                {
+                    "tool": name,
+                    "worker": self.config.name,
+                    "started_at": started_at,
+                    "ended_at": ended_at,
+                    "duration_ms": duration_ms,
+                    "error": str(e)
+                }
             )
             raise
 
@@ -737,15 +806,29 @@ class Agent:
             )
             
             # Get LLM decision
+            from datetime import datetime as _dt
+            think_started = _dt.utcnow().isoformat() + "Z"
+            think_start_time = time.time()
+            
             response = await self._llm_generate(user_prompt, system=system_prompt)
             logger.debug("[%s] LLM response: %s", self.config.name, str(response)[:500])
             
+            think_duration_ms = int((time.time() - think_start_time) * 1000)
+            think_ended = _dt.utcnow().isoformat() + "Z"
+            
             # Trace LLM thinking
             self._trace(
                 self.current_job_id or "unknown",
                 self.config.name,
                 "autonomous_think",
-                {"iteration": iteration, "response": response}
+                {
+                    "iteration": iteration,
+                    "worker": self.config.name,
+                    "started_at": think_started,
+                    "ended_at": think_ended,
+                    "duration_ms": think_duration_ms,
+                    "response": response
+                }
             )
             
             # Parse action from response
@@ -1124,6 +1207,22 @@ If you need to delegate:
 Rules for delegation:
 - Only use agent names from the list above; do NOT invent new agent names.
 - If none of the listed agents is appropriate, do not delegate; use tools or finish instead.
+
+## Parallel Processing (Sharding/Fan-out):
+When you have a large task that can be split into independent chunks:
+
+1. Use 'system_split_document' to divide content into sections:
+   {{"type":"tool","tool":"system_split_document","params":{{"document":"<text>","num_chunks":3}}}}
+
+2. Then use 'system_delegate_parallel' to process all chunks simultaneously:
+   {{"type":"tool","tool":"system_delegate_parallel","params":{{"agent":"researcher","tasks":["analyze chunk 1","analyze chunk 2","analyze chunk 3"]}}}}
+
+This pattern is ideal for:
+- Processing large documents in sections
+- Analyzing multiple sources concurrently
+- Any task that can be divided into independent subtasks
+
+The system will automatically wait for all parallel tasks to complete and return aggregated results.
 """
 
         system += """
