@@ -97,14 +97,55 @@ class EvenAgeConfig(BaseSettings):
     # Kafka (optional)
     kafka_bootstrap: str | None = Field(default=None, description="Kafka bootstrap servers (host:port)")
 
-    # MinIO/S3 Storage (optional, for large artifacts)
-    minio_endpoint: str = Field(default="localhost:9000", description="MinIO endpoint")
-    minio_access_key: str = Field(default="minioadmin", description="MinIO access key")
-    minio_secret_key: str = Field(
-        default="minioadmin123", description="MinIO secret key"
+    # S3-Compatible Storage (AWS S3, MinIO, or compatible services)
+    # For AWS S3: set endpoint to "s3.amazonaws.com", secure=True, and provide AWS credentials
+    # For MinIO: set endpoint to "localhost:9000" or "minio:9000", secure=False
+    storage_endpoint: str = Field(
+        default="localhost:9000",
+        description="S3-compatible storage endpoint (s3.amazonaws.com for AWS, localhost:9000 for MinIO)"
+    )
+    storage_access_key: str = Field(
+        default="minioadmin",
+        description="Storage access key (AWS Access Key ID or MinIO access key)"
+    )
+    storage_secret_key: str = Field(
+        default="minioadmin123",
+        description="Storage secret key (AWS Secret Access Key or MinIO secret key)"
+    )
+    storage_secure: bool = Field(
+        default=False,
+        description="Use HTTPS for storage (True for AWS S3, False for local MinIO)"
+    )
+    storage_region: str | None = Field(
+        default=None,
+        description="AWS region (e.g., 'us-east-1') - only needed for AWS S3"
+    )
+    storage_bucket: str = Field(
+        default="evenage",
+        description="Default storage bucket name"
+    )
+    
+    # Backward compatibility aliases (deprecated - use storage_* instead)
+    minio_endpoint: str | None = Field(
+        default=None,
+        description="[DEPRECATED] Use storage_endpoint instead"
+    )
+    minio_access_key: str | None = Field(
+        default=None,
+        description="[DEPRECATED] Use storage_access_key instead"
+    )
+    minio_secret_key: str | None = Field(
+        default=None,
+        description="[DEPRECATED] Use storage_secret_key instead"
+    )
+    minio_secure: bool | None = Field(
+        default=None,
+        description="[DEPRECATED] Use storage_secure instead"
+    )
+    minio_bucket: str | None = Field(
+        default=None,
+        description="[DEPRECATED] Use storage_bucket instead"
     )
-    minio_secure: bool = Field(default=False, description="Use HTTPS for MinIO")
-    minio_bucket: str = Field(default="evenage", description="Default bucket name")
 
     # Tracing and metrics (stored in DB, not external services)
     enable_tracing: bool = Field(default=True, description="Enable internal tracing to DB")
@@ -112,10 +153,10 @@ class EvenAgeConfig(BaseSettings):
 
     # Large Response Storage
     enable_large_response_storage: bool = Field(
-        default=True, description="Enable automatic storage of large responses in MinIO"
+        default=True, description="Enable automatic storage of large responses in S3-compatible storage"
     )
     storage_threshold_kb: int = Field(
-        default=100, description="Size threshold in KB for storing responses in MinIO"
+        default=100, description="Size threshold in KB for storing responses in S3-compatible storage"
     )
 
     # Inline workers: when running locally via AgentRunner, also spin up
@@ -176,6 +217,18 @@ class EvenAgeConfig(BaseSettings):
     groq_api_key: str | None = Field(
         default=None, description="Groq API key"
     )
+    xai_api_key: str | None = Field(
+        default=None, description="xAI Grok API key"
+    )
+    grok_api_key: str | None = Field(
+        default=None, description="xAI Grok API key (alias)"
+    )
+    together_api_key: str | None = Field(
+        default=None, description="Together AI API key (for Meta Llama)"
+    )
+    replicate_api_token: str | None = Field(
+        default=None, description="Replicate API token (for Meta Llama)"
+    )
     http_llm_endpoint: str | None = Field(default=None, description="Generic HTTP LLM endpoint URL")
 
     # Tool API keys (optional)
@@ -289,13 +342,20 @@ class BackendFactory:
 
         # Optionally enable large-response offload to storage
         try:
-            if getattr(self.config, "enable_large_response_storage", False):
+            if getattr(self.config, "enable_large_response_storage", True):
+                print(f"[STORAGE] Enabling large response storage (threshold={self.config.storage_threshold_kb} KB)")
                 storage = self.create_storage_backend()
                 bus._storage = storage
-                bus._storage_bucket = self.config.minio_bucket
+                # Use new storage_bucket field, fallback to old minio_bucket for compatibility
+                bucket = self.config.storage_bucket or self.config.minio_bucket or "evenage"
+                bus._storage_bucket = bucket
                 bus._storage_threshold_kb = self.config.storage_threshold_kb
-        except Exception:
+                print(f"[STORAGE] Configured: bucket={bucket}, threshold={self.config.storage_threshold_kb} KB")
+        except Exception as e:
             # Non-fatal: continue without offload
+            print(f"[STORAGE] Failed to enable storage: {e}")
+            import traceback
+            traceback.print_exc()
             pass
 
         return bus
@@ -322,6 +382,21 @@ class BackendFactory:
         if self.config.llm_backend == "gemini":
             from .llm import GeminiLLM
             return GeminiLLM(self.config.gemini_api_key, self.config.llm_model)
+        if self.config.llm_backend == "groq":
+            from .llm import GroqLLM
+            return GroqLLM(self.config.groq_api_key, self.config.llm_model)
+        if self.config.llm_backend == "grok":
+            from .llm import GrokLLM
+            return GrokLLM(self.config.xai_api_key or self.config.grok_api_key, self.config.llm_model)
+        if self.config.llm_backend == "meta":
+            from .llm import MetaLLM
+            # Default to Together AI, fallback to Replicate if Together key not set
+            provider = "together" if self.config.together_api_key else "replicate"
+            return MetaLLM(
+                self.config.together_api_key or self.config.replicate_api_token,
+                self.config.llm_model,
+                provider=provider
+            )
         if self.config.llm_backend == "http":
             from .llm import HTTPLLM
             if not self.config.http_llm_endpoint:
@@ -345,16 +420,36 @@ class BackendFactory:
         raise ValueError(f"Unknown cache_backend: {self.config.cache_backend}")
 
     def create_storage_backend(self):
-        """Create storage backend for artifacts (MinIO/S3)."""
-        if self.config.minio_endpoint:
-            from .storage import MinIOStorage
-            return MinIOStorage(
-                endpoint=self.config.minio_endpoint,
-                access_key=self.config.minio_access_key,
-                secret_key=self.config.minio_secret_key,
-                secure=self.config.minio_secure
+        """
+        Create S3-compatible storage backend (AWS S3, MinIO, or compatible).
+        
+        Supports backward compatibility with old minio_* field names.
+        """
+        # Use new storage_* fields, fallback to old minio_* fields for backward compatibility
+        endpoint = (
+            self.config.storage_endpoint
+            if self.config.storage_endpoint != "localhost:9000" or self.config.minio_endpoint is None
+            else self.config.minio_endpoint or self.config.storage_endpoint
+        )
+        access_key = self.config.minio_access_key or self.config.storage_access_key
+        secret_key = self.config.minio_secret_key or self.config.storage_secret_key
+        secure = (
+            self.config.minio_secure
+            if self.config.minio_secure is not None
+            else self.config.storage_secure
+        )
+        region = self.config.storage_region
+        
+        if endpoint:
+            from .storage import S3Storage
+            return S3Storage(
+                endpoint=endpoint,
+                access_key=access_key,
+                secret_key=secret_key,
+                secure=secure,
+                region=region
             )
-        # Fall back to in-memory storage if no MinIO configured
+        # Fall back to in-memory storage if no storage configured
         from .storage import InMemoryStorage
         return InMemoryStorage()
 
