@@ -11,7 +11,7 @@ from __future__ import annotations
 from collections.abc import Callable
 from typing import TypeVar
 
-from .agent import Agent
+from .agent_runtime import Agent
 
 
 T = TypeVar("T", bound=type[Agent])
@@ -24,7 +24,10 @@ def actor(
     backstory: str | None = None,
     allow_delegation: bool = True,
     max_iterations: int = 25,
-    tools: list | None = None
+    tools: list | None = None,
+    # Tracing controls
+    trace_enabled: bool = True,
+    trace_mask: list[str] | None = None,
 ) -> Callable[[T], T]:
     """
     Decorator to mark a class as an EvenAge actor (agent).
@@ -67,6 +70,9 @@ def actor(
         cls.ALLOW_DELEGATION = allow_delegation
         cls.MAX_ITERATIONS = max_iterations
         cls.TOOLS = tools or []
+        # Tracing config
+        cls.TRACE_ENABLED = bool(trace_enabled)
+        cls.TRACE_MASK = set(trace_mask or [])
 
         # Mark as actor
         cls.__evenage_actor__ = True
