@@ -516,45 +516,71 @@ class WorkerRunner:
         agent: Agent,
         database_url: str | None = None,
         redis_url: str | None = None,
+        storage_endpoint: str | None = None,
+        storage_access_key: str | None = None,
+        storage_secret_key: str | None = None,
+        storage_secure: bool | None = None,
+        storage_region: str | None = None,
+        # Backward compatibility
         minio_endpoint: str | None = None,
         minio_access_key: str | None = None,
         minio_secret_key: str | None = None,
         minio_secure: bool | None = None,
     ) -> None:
         # Build env config from provided values (fallback to defaults)
+        # Support both new storage_* and old minio_* parameter names
+        defaults = EvenAgeConfig()
         self.env_config = EvenAgeConfig(
-            database_url=database_url or EvenAgeConfig().database_url,
-            redis_url=redis_url or EvenAgeConfig().redis_url,
-            minio_endpoint=minio_endpoint or EvenAgeConfig().minio_endpoint,
-            minio_access_key=minio_access_key or EvenAgeConfig().minio_access_key,
-            minio_secret_key=minio_secret_key or EvenAgeConfig().minio_secret_key,
-            minio_secure=bool(minio_secure) if minio_secure is not None else EvenAgeConfig().minio_secure,
+            database_url=database_url or defaults.database_url,
+            redis_url=redis_url or defaults.redis_url,
+            storage_endpoint=storage_endpoint or minio_endpoint or defaults.storage_endpoint,
+            storage_access_key=storage_access_key or minio_access_key or defaults.storage_access_key,
+            storage_secret_key=storage_secret_key or minio_secret_key or defaults.storage_secret_key,
+            storage_secure=storage_secure if storage_secure is not None else (
+                minio_secure if minio_secure is not None else defaults.storage_secure
+            ),
+            storage_region=storage_region or defaults.storage_region,
+            storage_bucket=defaults.storage_bucket,  # Read from env
+            enable_large_response_storage=defaults.enable_large_response_storage,  # Read from env
+            storage_threshold_kb=defaults.storage_threshold_kb,  # Read from env
         )
         self.factory = BackendFactory(self.env_config)
         self.agent = agent
 
     async def start(self) -> None:
         """Start processing tasks indefinitely for the agent's queue."""
+        # Create bus from factory to ensure proper configuration (Kafka, Redis, etc.)
+        bus = self.factory.create_queue_backend()
+        
+        # Replace agent's bus with the correctly configured one
+        self.agent.bus = bus
+        
         # Ensure agent is connected/registered
         try:
             await self.agent.connect_bus()
-        except Exception:
-            pass
+            print(f"[WorkerRunner] Agent {self.agent.config.name} connected to bus")
+        except Exception as e:
+            print(f"[WorkerRunner] Failed to connect agent to bus: {e}")
 
-        bus = self.agent.bus or self.factory.create_queue_backend()
         agent_name = self.agent.config.name
+        print(f"[WorkerRunner] Starting consume loop for agent: {agent_name}")
 
         while True:
             tasks = await bus.consume_tasks(agent_name, block_ms=2000, count=5)
             if not tasks:
+                print(f"[WorkerRunner] No tasks for {agent_name}, continuing...")
                 continue
+            print(f"[WorkerRunner] Received {len(tasks)} task(s) for {agent_name}")
             for message in tasks:
                 task_id = message.get("task_id")
                 payload = message.get("payload", {})
+                print(f"[WorkerRunner] Processing task {task_id}")
                 try:
                     result = await self.agent.handle(payload)
                     if task_id:
                         await bus.publish_response(task_id, result)
+                        print(f"[WorkerRunner] Published response for task {task_id}")
                 except Exception as e:
+                    print(f"[WorkerRunner] Error processing task {task_id}: {e}")
                     if task_id:
                         await bus.publish_response(task_id, {"status": "error", "error": str(e)})
