@@ -1,8 +1,8 @@
 import asyncio
 import json
 from evenage.core import EvenAgeConfig
-from evenage.core.backends.queue import MemoryBus
-from evenage.core.backends.storage import InMemoryStorage
+from evenage.core.message_bus import MemoryBus
+from evenage.core.storage import InMemoryStorage
 
 
 def test_offload_on_large_response():
